==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_es.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Al parecer finalmente llegamos.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("¿Crees que aquí es?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("¿Cómo puede caber todo esto en un diskette de tres y media pulgadas?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Mira que tan grande es comparado conmigo. Es un diskette de tres y medio metros.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Eso es mejor. Gran plan, gran disco. Eso tiene sentido.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("¿Crees que podamos levantarlo?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Va a ser difícil.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("No creo que pueda ser posible. ¿Porqué estarían escondiéndose aquí, si podemos levantarlo?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("¡Calla, o te romperé tus patas!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("¿Puedes ver esa cruz de acero? Esta es la tumba de nuestras esperanzas.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("No seas siempre tan melancólico. No puedo aguantarlo.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("¿No sería suficiente descargar ese plan desde el diskette a nuestro notebook?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Porqué no. Sácalo.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, ¡Maldita sea! Lo dejé en la casa.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("¿Regresamos a buscarlo?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nunca. Podría ser entretenido para ti, pero mis aletas están adoloridas.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Divertido. Me pregunto cómo lo vas a hacer ahora.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("¿Qué tal si no hubiera un plan en este diskette? ¿Qué tal si está aquí sólo para confundirnos?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("No lo creo. ¿Hay otro objeto que fuera más difícil de sacar?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("¿Qué clase de pequeñas criaturas son aquellas?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Esos deben ser virus informáticos.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Aahh. Esos monstruos.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Por sobre todo, debemos de ser cuidadosos de no tomarlos con el disco. El jugador no estaría contento si los volcamos en su escritorio.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Nuestra meta es empujar ese disco.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("¡No me moverás fácilmente!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("¡Eso fué elegante!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Uuups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("¡Maldición!")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("¡Déjame solo!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_es.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Al parecer finalmente llegamos.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("¿Crees que aquí es?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("¿Cómo puede caber todo esto en un diskette de tres y media pulgadas?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Mira que tan grande es comparado conmigo. Es un diskette de tres y medio metros.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Eso es mejor. Gran plan, gran disco. Eso tiene sentido.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("¿Crees que podamos levantarlo?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Va a ser difícil.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("No creo que pueda ser posible. ¿Porqué estarían escondiéndose aquí, si podemos levantarlo?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("¡Calla, o te romperé tus patas!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("¿Puedes ver esa cruz de acero? Esta es la tumba de nuestras esperanzas.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("No seas siempre tan melancólico. No puedo aguantarlo.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("¿No sería suficiente descargar ese plan desde el diskette a nuestro notebook?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Porqué no. Sácalo.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, ¡Maldita sea! Lo dejé en la casa.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("¿Regresamos a buscarlo?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Nunca. Podría ser entretenido para ti, pero mis aletas están adoloridas.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Divertido. Me pregunto cómo lo vas a hacer ahora.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("¿Qué tal si no hubiera un plan en este diskette? ¿Qué tal si está aquí sólo para confundirnos?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("No lo creo. ¿Hay otro objeto que fuera más difícil de sacar?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("¿Qué clase de pequeñas criaturas son aquellas?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Esos deben ser virus informáticos.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Aahh. Esos monstruos.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Por sobre todo, debemos de ser cuidadosos de no tomarlos con el disco. El jugador no estaría contento si los volcamos en su escritorio.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Nuestra meta es empujar ese disco.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("¡No me moverás fácilmente!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("¡Eso fué elegante!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Uuups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("¡Maldición!")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("¡Déjame solo!")
